@@ -109,7 +109,7 @@ analyze_time_clusters.time_cluster_data <-function(data,
     }
   }
   if (quiet) pbsapply <- sapply
-
+  
   # Arg check:
   if (is.null(formula)) {
     formula <-attrs$formula
@@ -513,7 +513,7 @@ make_time_cluster_data.time_sequence_data <- function(data,
 
   # Output data, add attributes w/ relevant info
   df_timeclust <- as.data.frame(df_timeclust)
-  class(df_timeclust) <-c("time_cluster_data", "time_sequence_data", class(df_timeclust))
+  class(df_timeclust) <- unique(c("time_cluster_data", "time_sequence_data", "eyetrackingR_df", class(df_timeclust)))
   attr(df_timeclust, "eyetrackingR") <- c(attrs,
                                          list(clusters = clusters,
                                               predictor_column = predictor_column,
